@@ -213,8 +213,8 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                     self._exec(f"{install_exe} lib install ArduinoJson")
                     self._exec(f"{install_exe} lib install ArduinoMqttClient")
                     self._exec(f"{install_exe} lib install FastLED")
-                    self._exec(f"{install_exe} lib install TinyGPSPlus-ESP32")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Core2.git")
+                    self._exec(f"{install_exe} lib install --git-url https://github.com/Tinyu-Zhao/TinyGPSPlus-ESP32.git")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Unit-ENV.git")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENCODER.git")
                     self._exec(f"{install_exe} lib install --git-url https://github.com/aws-samples/arduino-aws-greengrass-iot.git")
@@ -253,8 +253,8 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                 self._exec(f"{install_exe} lib install ArduinoJson")
                 self._exec(f"{install_exe} lib install ArduinoMqttClient")
                 self._exec(f"{install_exe} lib install FastLED")
-                self._exec(f"{install_exe} lib install TinyGPSPlus-ESP32")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Core2.git")
+                self._exec(f"{install_exe} lib install --git-url https://github.com/Tinyu-Zhao/TinyGPSPlus-ESP32.git")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/M5Unit-ENV.git")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/m5stack/UNIT_ENCODER.git")
                 self._exec(f"{install_exe} lib install --git-url https://github.com/aws-samples/arduino-aws-greengrass-iot.git")
@@ -328,7 +328,7 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
                         print(f" + Exec: {cmd}")
                     self._exec(cmd)
 
-                    cmd = f"{install_exe} lib install TinyGPSPlus-ESP32"
+                    cmd = f"{install_exe} lib install --git-url https://github.com/Tinyu-Zhao/TinyGPSPlus-ESP32.git"
                     if verbose:
                         print(f" + Exec: {cmd}")
                     self._exec(cmd)
@@ -411,6 +411,9 @@ class ToolchainESP32Arduino_1_0_0(ToolChainBase):
     # Each platform will have a different way of determining it.
     # If the tool hasn't been installed yet, we just return "***".
     #
+    # NOTE NOTE NOTE: This returns the ESPTool version, which will be different than the Arduino-CLI
+    # tool version.
+    #
     def get_installed_toolchain_version(self, install_path=None):
         result = None
         try:
